@@ -1,7 +1,13 @@
+"""Atomic Errors
+
+Error Classes for the package"""
+
+
 class RequestFailedError(Exception):
     """Exception called when an API request fails"""
 
     def __init__(self):
+        super().__init__(self)
         self.message = "The request did not succeed."
 
     def __str__(self):
@@ -9,11 +15,13 @@ class RequestFailedError(Exception):
 
 
 class AssetIDError(Exception):
-    """Exception called when Asset ID is invalid"""
+    """Exception called when Atomic ID is invalid"""
 
     def __init__(self, asset_id):
+        super().__init__(self)
         self.message = (
-            "Asset ID %s is invalid. The asset ID must be an integer." % asset_id
+            "Atomic ID %s is invalid. The Atomic ID must be a string integer."
+            % asset_id
         )
 
     def __str__(self):
@@ -24,6 +32,7 @@ class NoFiltersError(Exception):
     """Exception called when no filters are provided"""
 
     def __init__(self):
+        super().__init__(self)
         self.message = "This method requires at least one argument."
 
     def __str__(self):
@@ -34,6 +43,7 @@ class NoCollectionImageError(Exception):
     """Exception called when a collection has no image"""
 
     def __init__(self):
+        super().__init__(self)
         self.message = "This collection has no image."
 
     def __str__(self):
